=== modified file 'NEWS'
--- NEWS	2007-02-22 14:28:19 +0000
+++ NEWS	2007-02-25 12:10:53 +0000
@@ -124,6 +124,9 @@
 
     * Fix problem with UNC paths on Windows 98. (Alexander Belchenko, #84728)
 
+    * Invalid proxy env variables should not cause a traceback.
+      (Vincent Ladeuil, #87765)
+
   TESTING:
 
     * New ``--first`` option to ``bzr selftest`` to run specified tests

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2007-02-08 17:01:20 +0000
+++ bzrlib/tests/test_http.py	2007-02-25 12:10:53 +0000
@@ -637,7 +637,10 @@
 
 
 class TestHttpProxyWhiteBox(TestCase):
-    """Whitebox test proxy http authorization."""
+    """Whitebox test proxy http authorization.
+
+    These tests concern urllib implementation only.
+    """
 
     def setUp(self):
         TestCase.setUp(self)
@@ -685,6 +688,10 @@
         self.assertEqual('Basic ' + 'joe:foo'.encode('base64').strip(),
                          request.headers['Proxy-authorization'])
 
+    def test_invalid_proxy(self):
+        """A proxy env variable without scheme"""
+        self._install_env({'http_proxy': 'host:1234'})
+        self.assertRaises(errors.InvalidURL, self._proxied_request)
 
 
 class TestProxyHttpServer(object):
@@ -716,7 +723,9 @@
                                   ('foo-proxied', 'proxied contents of foo\n')])
         # Let's setup some attributes for tests
         self.server = self.get_readonly_server()
-        self.no_proxy_host = 'localhost:%d' % self.server.port
+        # FIXME: We should not rely on 'localhost' being the hostname
+        self.proxy_address = 'localhost:%d' % self.server.port
+        self.no_proxy_host = self.proxy_address
         # The secondary server is the proxy
         self.proxy = self.get_secondary_server()
         self.proxy_url = self.proxy.get_url()
@@ -786,6 +795,11 @@
         self.not_proxied_in_env({'ALL_PROXY': self.proxy_url,
                                  'NO_PROXY': self.no_proxy_host})
 
+    def test_http_proxy_without_scheme(self):
+        self.assertRaises(errors.InvalidURL,
+                          self.proxied_in_env,
+                          {'http_proxy': self.proxy_address})
+
 
 class TestProxyHttpServer_urllib(TestProxyHttpServer,
                                  TestCaseWithTwoWebservers):
@@ -814,6 +828,13 @@
     def test_HTTP_PROXY_with_NO_PROXY(self):
         raise TestSkipped()
 
+    def test_http_proxy_without_scheme(self):
+        # pycurl *ignores* invalid proxy env variables. If that
+        # ever change in the future, this test will fail
+        # indicating that pycurl do not ignore anymore such
+        # variables.
+        self.not_proxied_in_env({'http_proxy': self.proxy_address})
+
 
 class TestRanges(object):
     """Test the Range header in GET methods..

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2007-02-08 17:01:20 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2007-02-25 12:10:53 +0000
@@ -702,9 +702,14 @@
         if self._debuglevel > 0:
             print 'set_proxy %s_request for %r' % (type, proxy)
         orig_type = request.get_type()
-        type, r_type = urllib.splittype(proxy)
-        host, XXX = urllib.splithost(r_type)
-        if '@' in host:
+        scheme, r_scheme = urllib.splittype(proxy)
+        if self._debuglevel > 0:
+            print 'scheme: %s, r_scheme: %s' % (scheme, r_scheme)
+        host, XXX = urllib.splithost(r_scheme)
+        if host is None:
+            raise errors.InvalidURL(proxy,
+                                    'Invalid syntax in proxy env variable')
+        elif '@' in host:
             user_pass, host = host.split('@', 1)
             if ':' in user_pass:
                 user, password = user_pass.split(':', 1)

